@@ -12,9 +12,33 @@ class Visualiser:
     def __init__(self, img: Image.Image, font_path: Optional[str] = None, font_size=30):
         copy = True
         self.img = deepcopy(img) if copy else img
-        self.base_font_size = font_size
+        self.font_size = font_size
         self.font_path = font_path or DEFAULT_FONT_PATH
 
+    @staticmethod
+    def _as_int_array(img_array: np.ndarray):
+        assert img_array.ndim == 3
+        return np.ascontiguousarray(img_array, np.uint8)
+
+    @classmethod
+    def fromarray_RGB(
+        cls, img_array: np.ndarray, font_path: Optional[str] = None, font_size=30
+    ):
+        img_array = cls._as_int_array(img_array)
+        return cls(Image.fromarray(img_array), font_path, font_size)
+
+    @classmethod
+    def fromarray_BGR(
+        cls, img_array: np.ndarray, font_path: Optional[str] = None, font_size=30
+    ):
+        return cls.fromarray_RGB(img_array[:, :, ::-1], font_path, font_size)
+
+    @classmethod
+    def from_file(
+        cls, filepath: PathLike, font_path: Optional[str] = None, font_size=30
+    ):
+        return cls(Image.open(filepath).convert("RGB"), font_path, font_size)
+
     def _repr_png_(self):
         return self.img._repr_png_()
 
@@ -105,8 +129,8 @@ class Visualiser:
     def draw_bbox(
         self,
         xyxy,
-        label: str,
-        label_transform: Callable = str.upper,
+        label: Optional[str] = None,
+        label_transform: Callable = str.title,
         label_location: Literal["top", "bottom"] = "bottom",
         confidence: Optional[float] = None,
         style: Literal["rounded", "sharp"] = "rounded",
@@ -128,9 +152,14 @@ class Visualiser:
                 xyxy, corner_radius, box_fill, border_opacity, border_width
             )
 
-        label = label_transform(label)
-        if confidence:
-            label = f"{label}: {round(confidence*100, 1)}%"
+        # fmt: off
+        if label:      label = label_transform(label)
+        if confidence: confidence = round(confidence * 100, 1)
+
+        if   label and confidence:     label = f"{label}: {confidence}%"
+        elif label and not confidence: label = label
+        elif confidence and not label: label = f"{confidence} %"
+        # fmt: on
 
         self.img = self.draw_text_within_xyxy(
             xyxy,
@@ -161,7 +190,7 @@ class Visualiser:
             xyxy=xyxy,
             label=label,
             font_path=self.font_path,
-            base_font_size=self.base_font_size,
+            base_font_size=self.font_size,
             pad_percentage=font_pad,
             text_color=font_fill,
             location=label_location,
@@ -175,8 +204,6 @@ class Visualiser:
         self,
         text: Union[str, List[str]],
         position: TEXT_POSITIONS,
-        # font_path: Optional[PathLike] = None,
-        # font_size: int = 30,
         font_border=False,
         font_color=(255, 255, 255),
         font_border_color=(0, 0, 0),
@@ -190,7 +217,7 @@ class Visualiser:
             text=text,
             position=position,
             font_path=self.font_path,
-            font_size=self.base_font_size,
+            font_size=self.font_size,
             font_border=font_border,
             font_color=font_color,
             font_border_color=font_border_color,
@@ -208,4 +235,6 @@ class Visualiser:
         return self.img
 
     def draw_rule_of_thirds(self, thickness=5, opacity=0.4):
-        return draw_rule_of_thirds(self.img, thickness, opacity)
+        self.draw_vertical_bars([1 / 3, 2 / 3], thickness=thickness, opacity=opacity)
+        self.draw_horizontal_bars([1 / 3, 2 / 3], thickness=thickness, opacity=opacity)
+        return self
